@@ -1,10 +1,9 @@
 """ Loading Raw data """
 import logging
 from dataclasses import dataclass
-from datetime import datetime
 from numbers import Number
 from pathlib import Path
-from typing import List, Optional, Tuple, Union
+from typing import List, Tuple, Union
 
 import numpy as np
 import pandas as pd
@@ -23,8 +22,6 @@ class SunDataSource(DataSource):
     """Add azimuth and elevation angles of the sun."""
 
     zarr_path: Union[str, Path]
-    start_dt: Optional[datetime] = None
-    end_dt: Optional[datetime] = None
 
     def __post_init__(self):
         """Post Init"""
@@ -91,14 +88,17 @@ class SunDataSource(DataSource):
 
         logger.info(f"Loading Sun data from {self.zarr_path}")
 
-        self.azimuth, self.elevation = load_from_zarr(
-            zarr_path=self.zarr_path, start_dt=self.start_dt, end_dt=self.end_dt
-        )
+        self.azimuth, self.elevation = load_from_zarr(zarr_path=self.zarr_path)
 
     def get_locations(self, t0_datetimes: pd.DatetimeIndex) -> Tuple[List[Number], List[Number]]:
         """Sun data should not be used to get batch locations"""
         raise NotImplementedError("Sun data should not be used to get batch locations")
 
-    def datetime_index(self) -> pd.DatetimeIndex:
+    def datetime_index(self):
         """The datetime index of this datasource"""
-        return self.azimuth.index
+        return NotImplementedError(
+            "Sun data should not be used for datetime_index. "
+            "This is because normally the data is available all the time, "
+            "except for when using test data. "
+            "This is becasue data from 2019 is extrapolate on to other years. "
+        )
